@@ -201,11 +201,13 @@ class Client:
     def wrap_notion_emoji(self, notion_data):
         return self.instantiate_class("emoji", None, self, notion_data)
 
-    def wrap_notion_rich_text_array(self, notion_data, block=None):
-        return self.instantiate_class("rich_text_array", None, self, notion_data, block)
+    def wrap_notion_rich_text_array(self, notion_data, block=None, table=None):
+        return self.instantiate_class("rich_text_array", None, self, notion_data, block, table)
 
-    def wrap_notion_rich_text(self, notion_data, block=None):
-        return self.instantiate_class("rich_texts", notion_data["type"], self, notion_data, block)
+    def wrap_notion_rich_text(self, notion_data, block=None, table=None):
+        return self.instantiate_class(
+            "rich_texts", notion_data["type"], self, notion_data, block, table
+        )
 
     def wrap_notion_mention(self, notion_data, plain_text, block=None):
         # here we pass in the plain_text to avoid the need to query the page
@@ -363,8 +365,8 @@ class Client:
         """
         Download a file from a given URL into the MEDIA_ROOT.
 
-        Preserve the file extension from the URL, but use the name of the parent
-        page followed by an md5 hash.
+        Preserve the file extension from the URL, but use the
+        id of the block followed by an md5 hash.
         """
         url_path = path.basename(urlparse(url).path)
         _, extension = path.splitext(url_path)
