@@ -66,7 +66,7 @@ class MermaidFencedCodeBlock(FencedCodeBlock):
             ], capture_output=True, input=diagram_as_bytes, check=True)
             with open(temp_filepath, 'rb') as temp_file:
                 content = temp_file.read()
-                root = root = Path(__file__).resolve().parent.parent
+                root = Path(__file__).resolve().parent.parent
                 with open(root/'data'/'mermaid_err.png', 'rb') as err_img:
                     if content == err_img.read():
                         raise NotImplementedError(
